@@ -3,7 +3,7 @@ package DBIx::BatchChunker;
 our $AUTHORITY = 'cpan:GSG';
 # ABSTRACT: Run large database changes safely
 use version;
-our $VERSION = 'v0.941.0'; # VERSION
+our $VERSION = 'v0.941.1'; # VERSION
 
 use Moo;
 use MooX::StrictConstructor;
@@ -1390,6 +1390,18 @@ sub _chunk_count_checker {
         $ls->prev_check('skipped rows');
         return 0;
     }
+    elsif ($ls->end - $ls->start <= 0) {
+        # Down to a single ID: We _have_ to process it
+        $ls->prev_check('at a single ID');
+
+        # Complain, because this can be dangerous with a wild enough Row:ID ratio
+        if ($ls->chunk_count > 1) {
+            $progress->message('WARNING: Processing a single ID with many rows attached because resizing cannot proceed any further.');
+            $progress->message('Consider flipping the relationship so that IDs and row counts are 1:1.');
+        }
+
+        return 1;
+    }
     elsif ($chunk_percent > 1 + $self->min_chunk_percent) {
         # Too many rows: Backtrack to the previous range and try to bisect
         $self->_print_debug_status('shrunk');
@@ -1410,8 +1422,9 @@ sub _chunk_count_checker {
         return 0;
     }
 
-    # The above two are more important than skipping the count checks.  Better to
-    # have too few rows than too many.
+    # The above three are more important than skipping the count checks.  Better to
+    # have too few rows than too many.  The single ID check prevents infinite loops
+    # from bisecting, though.
 
     elsif ($ls->checked_count > 10) {
         # Checked too many times: Just process it
@@ -1658,7 +1671,7 @@ DBIx::BatchChunker - Run large database changes safely
 
 =head1 VERSION
 
-version v0.941.0
+version v0.941.1
 
 =head1 SYNOPSIS
 
@@ -2238,7 +2251,7 @@ Grant Street Group <developers@grantstreet.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 - 2021 by Grant Street Group.
+This software is Copyright (c) 2018 - 2022 by Grant Street Group.
 
 This is free software, licensed under:
 
